<?php

namespace Drupal\webform_autocomplete_select2\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\Core\Url;
use Drupal\select2\Element\Select2;

/**
 * Provides a 'webform_autocomplete_select2_element'.
 *
 * Webform elements are just wrappers around form elements, therefore every
 * webform element must have correspond FormElement.
 *
 * Below is the definition for a custom 'webform_autocomplete_select2_element' which just
 * renders a simple text field.
 *
 * @FormElement("webform_autocomplete_select2")
 *
 * @see \Drupal\Core\Render\Element\FormElement
 * @see https://api.drupal.org/api/drupal/core%21lib%21Drupal%21Core%21Render%21Element%21FormElement.php/class/FormElement
 * @see \Drupal\Core\Render\Element\RenderElement
 * @see https://api.drupal.org/api/drupal/namespace/Drupal%21Core%21Render%21Element
 * @see \Drupal\webform_example_element\Element\WebformExampleElement
 */
class WebformAutocompleteSelect2Element extends Select2 {

  /**
   * {@inheritdoc}
   */
  /**
   * {@inheritdoc}
   */
  public function getInfo(): array {
    $info = parent::getInfo();
    return $info;
  }

  /**
   * Webform element changes babses on settings.
   */
  public static function processSelect(&$element, FormStateInterface $form_state, &$complete_form): array {
    parent::processSelect($element, $form_state, $complete_form);
    unset($element["#needs_validation"]);
    if (isset($element['#autocomplete_start']) && $element['#autocomplete_start']) {
      $element['#select2']['minimumInputLength'] = $element['#autocomplete_start'];
    }
    if (isset($element['#multiple']) && is_numeric($element['#multiple'])) {
      $element['#select2']['maximumSelectionLength'] = $element['#multiple'];
    }
     if (empty($element['#select2']['dropdownParent']) && !empty($complete_form['#id'])) {
      $element['#select2']['dropdownParent'] = '#' . $complete_form['#id'];
    }
    return $element;
  }

  /**
   * Prepares select2 .
   *
   * @param array $element
   *   An associative array containing the properties of the element.
   *   Properties used: #title, #value, #description, #size, #maxlength,
   *   #placeholder, #required, #attributes.
   *
   * @return array
   *   The $element with prepared variables ready for theme_element().
   */
  public static function preRenderAutocomplete(array $element): array {
    $url = Url::fromRoute($element['#autocomplete_route_name'])
      ->toString(TRUE);

    $element['#attributes']['data-select2-config'] += [
        'minimumInputLength' => 1,
        'ajax' => [
          'delay' => 250,
          'url' => $url->getGeneratedUrl(),

        ],
      ];
    return $element;
  }

}

