<?php

namespace Drupal\webform_autocomplete_select2\Plugin\WebformElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformElement\Select;

/**
 * Provides a 'webform_example_element' element.
 *
 * @WebformElement(
 *   id = "webform_autocomplete_select2",
 *   label = @Translation("Webform Autocomplete Select2"),
 *   description = @Translation("Provides a webform Autocomplete Select2 element."),
 *   category = @Translation("Advanced elements"),
 * )
 *
 * @see \Drupal\webform_example_element\Element\WebformExampleElement
 * @see \Drupal\webform\Plugin\WebformElementBase
 * @see \Drupal\webform\Annotation\WebformElement
 */
class WebformAutocompleteSelect2Element extends Select {

  /**
   * {@inheritdoc}
   */
  protected function defineDefaultProperties() {
    // Here you define your webform element's default properties,
    // which can be inherited.
    //
    // @see \Drupal\webform\Plugin\WebformElementBase::defaultProperties
    // @see \Drupal\webform\Plugin\WebformElementBase::defaultBaseProperties
    $properties = [
        'autocomplete_route_name' => '',
        'autocomplete_route_parameterse' => '',
        'autocomplete_options_callback' => 'default',
        'autocomplete_start' => '',
      ] + parent::defineDefaultProperties();
    return $properties;
  }

  /****************************************************************************/


  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    unset($form['options']);
    unset($form['options_other']);
    $form['select2_autocomplete'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Select2 Autocomplete settings'),
    ];

    $form['select2_autocomplete']['autocomplete_route_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Autocomplete route name'),
      '#description' => $this->t("Enter valid route name."),
      '#required' => TRUE
    ];
    $form['select2_autocomplete']['autocomplete_route_parameterse'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Autocomplete route parameters'),
      '#description' => $this->t("Enter the route parameters with comma seperator."),
      '#return_value' => TRUE,
    ];
    $form['select2_autocomplete']['autocomplete_start'] = [
      '#type' => 'number',
      '#title' => $this->t('Autocomplete request will go based on this number.'),
      '#description' => $this->t("Autocomplete request will go based on this number."),
      '#return_value' => TRUE,
    ];
    return $form;
  }
}

